==> haskell-optparse-generic-1.3.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-generic
version: 1.3.0
id: optparse-generic-1.3.0-LvkmBt2zoxZ4iVZwOU1t6R
key: optparse-generic-1.3.0-LvkmBt2zoxZ4iVZwOU1t6R
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.
    .
    See the documentation in "Options.Generic" for an example of how to use
    this library
category: System
abi: 46ef566b5cfc4bf0a6198b25ab17fe18
exposed: True
exposed-modules:
    Options.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-generic-1.3.0
hs-libraries: HSoptparse-generic-1.3.0-LvkmBt2zoxZ4iVZwOU1t6R
depends:
    Only-0.1-4eYnxvcrr7tEbYgCvIkHLb base-4.12.0.0 bytestring-0.10.8.2
    optparse-applicative-0.15.1.0-3zohG31eF19CsmDcrOZBbb
    system-filepath-0.4.14-GStLucmxMDgJ6I3eQ2JLLu text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock
haddock-html: /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-generic-1.3.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-generic
version: 1.3.0
id: optparse-generic-1.3.0-KkULzSEMlvIHm6Iz57T2N
key: optparse-generic-1.3.0-KkULzSEMlvIHm6Iz57T2N
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.
    .
    See the documentation in "Options.Generic" for an example of how to use
    this library
category: System
abi: 5536203e9b5124a4ebed86097512dec5
exposed: True
exposed-modules:
    Options.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/optparse-generic-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/optparse-generic-1.3.0
hs-libraries: HSoptparse-generic-1.3.0-KkULzSEMlvIHm6Iz57T2N
depends:
    Only-0.1-4eYnxvcrr7tEbYgCvIkHLb base-4.12.0.0 bytestring-0.10.8.2
    optparse-applicative-0.15.1.0-3zohG31eF19CsmDcrOZBbb
    system-filepath-0.4.14-8V9CH9ujwNBBydA2SorUtz text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock
haddock-html: /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
